#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['drf_lighten']

package_data = \
{'': ['*'], 'drf_lighten': ['.ropeproject/*']}

setup(name='drf_lighten',
      version='0.2.1',
      description='A way to remove unwanted fields from a serializer',
      author='Henock Tesfaye',
      author_email='jupiter.jupiter1@gmail.com',
      url=None,
      packages=packages,
      package_data=package_data,
     )
